@@ -94,11 +94,7 @@ class Scraper:
         else:
             now = datetime.now()
             milliseconds_ = int(now.microsecond / 1000.)
-            self.now = now.strftime('{start}{milli:03d}{end}'.format(
-                start=self.pattern[0:milliseconds.start()],
-                milli=milliseconds_,
-                end=self.pattern[milliseconds.end():]
-            ))
+            self.now = now.strftime(f'{self.pattern[0:milliseconds.start()]}{milliseconds_:03d}{self.pattern[milliseconds.end():]}')
 
     def matches(self, filepath, date):
         return date.strftime(self.pattern) == filepath
